interface Options {
    body?: any;
    headers?: Record<any, any>;
    /** `content-type`, default value: If body is an object "application/json", otherwise "text/plain;charset=UTF-8" */
    contentType?: string;
}
export type CreateResponse<K extends Readonly<keyof StatusText>, Status extends number, OK extends boolean, T extends Record<any, any>> = APIResponse<{
    [Key in K]: () => Simplify<T & {
        status: Status;
        ok: OK;
    }>;
}> | GeneralResponse<K, Status, OK, T>;
type GeneralResponse<K extends Readonly<keyof StatusText>, Status extends Readonly<number>, OK extends Readonly<boolean>, T extends Record<any, any>> = APIResponse<{
    [Property in StatusClass[K]]: () => Simplify<T & {
        status: Status;
        ok: OK;
    }>;
}>;
export declare const 
/** [100 Continue](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/100) — indicates that everything so far is OK and that the client should continue with the request or ignore it if it is already finished. */
Continue: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Continue: () => Simplify<T & {
        status: 100;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Continue", 100, false, T>, 
/** [101 Switching Protocols](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/101) — indicates a protocol to which the server switches. The protocol is specified in the [Upgrade](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Upgrade) request header received from a client. */
SwitchingProtocols: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    SwitchingProtocols: () => Simplify<T & {
        status: 101;
        ok: false;
    }, {}>;
}> | GeneralResponse<"SwitchingProtocols", 101, false, T>, 
/** [102 Processing](https://www.webfx.com/web-development/glossary/http-status-codes/what-is-a-102-status-code/) — An interim response used to inform the client that the server has accepted the complete request but has not yet completed it. */
Processing: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Processing: () => Simplify<T & {
        status: 102;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Processing", 102, false, T>, 
/** [103 Early Hints](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/103) — is primarily intended to be used with the [Link](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Link) header to allow the user agent to start preloading resources while the server is still preparing a response. */
EarlyHints: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    EarlyHints: () => Simplify<T & {
        status: 103;
        ok: false;
    }, {}>;
}> | GeneralResponse<"EarlyHints", 103, false, T>, 
/** [200 OK](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/200) — indicates that the request has succeeded. A 200 response is cacheable by default. */
Ok: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Ok: () => Simplify<T & {
        status: 200;
        ok: true;
    }, {}>;
}> | GeneralResponse<"Ok", 200, true, T>, 
/** [201 Created](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/201) — indicates that the request has succeeded and has led to the creation of a resource. The new resource is effectively created before this response is sent back and the new resource is returned in the body of the message, its location being either the URL of the request, or the content of the [Location](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Location) header. */
Created: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Created: () => Simplify<T & {
        status: 201;
        ok: true;
    }, {}>;
}> | GeneralResponse<"Created", 201, true, T>, 
/** [202 Accepted](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/202) — indicates that the request has been accepted for processing, but the processing has not been completed; in fact, processing may not have started yet. The request might or might not eventually be acted upon, as it might be disallowed when processing actually takes place. */
Accepted: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Accepted: () => Simplify<T & {
        status: 202;
        ok: true;
    }, {}>;
}> | GeneralResponse<"Accepted", 202, true, T>, 
/** [203 Non-Authoritative Information](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/203) — indicates that the request was successful but the enclosed payload has been modified by a transforming [proxy](https://developer.mozilla.org/en-US/docs/Glossary/Proxy_server) from that of the origin server's [200](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/200) (OK) response. */
NonAuthoritativeInformation: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NonAuthoritativeInformation: () => Simplify<T & {
        status: 203;
        ok: true;
    }, {}>;
}> | GeneralResponse<"NonAuthoritativeInformation", 203, true, T>, 
/** [204 No Content](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/204) — indicates that a request has succeeded, but that the client doesn't need to navigate away from its current page. */
NoContent: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NoContent: () => Simplify<T & {
        status: 204;
        ok: true;
    }, {}>;
}> | GeneralResponse<"NoContent", 204, true, T>, 
/** [205 Reset Content](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/205) — tells the client to reset the document view, so for example to clear the content of a form, reset a canvas state, or to refresh the UI. */
ResetContent: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    ResetContent: () => Simplify<T & {
        status: 205;
        ok: true;
    }, {}>;
}> | GeneralResponse<"ResetContent", 205, true, T>, 
/** [206 Partial Content](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/206) — indicates that the request has succeeded and the body contains the requested ranges of data, as described in the Range header of the request. */
PartialContent: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PartialContent: () => Simplify<T & {
        status: 206;
        ok: true;
    }, {}>;
}> | GeneralResponse<"PartialContent", 206, true, T>, 
/** [207 Mutli-Status](https://www.webfx.com/web-development/glossary/http-status-codes/what-is-a-207-status-code/) — conveys information about multiple resources in situations where multiple status codes might be appropriate. */
MultiStatus: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    MultiStatus: () => Simplify<T & {
        status: 207;
        ok: true;
    }, {}>;
}> | GeneralResponse<"MultiStatus", 207, true, T>, 
/** [208 Already Reported](https://www.webfx.com/web-development/glossary/http-status-codes/what-is-a-208-status-code/) — Used inside a DAV: propstat response element to avoid enumerating the internal members of multiple bindings to the same collection repeatedly. */
AlreadyReported: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    AlreadyReported: () => Simplify<T & {
        status: 208;
        ok: true;
    }, {}>;
}> | GeneralResponse<"AlreadyReported", 208, true, T>, 
/** [226 IM Used](https://www.webfx.com/web-development/glossary/http-status-codes/what-is-a-226-status-code/) — The server has fulfilled a GET request for the resource, and the response is a representation of the result of one or more instance-manipulations applied to the current instance. */
IMUsed: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    IMUsed: () => Simplify<T & {
        status: 226;
        ok: true;
    }, {}>;
}> | GeneralResponse<"IMUsed", 226, true, T>, MultipleChoices: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    MultipleChoices: () => Simplify<T & {
        status: 300;
        ok: false;
    }, {}>;
}> | GeneralResponse<"MultipleChoices", 300, false, T>, MovedPermanently: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    MovedPermanently: () => Simplify<T & {
        status: 301;
        ok: false;
    }, {}>;
}> | GeneralResponse<"MovedPermanently", 301, false, T>, Found: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Found: () => Simplify<T & {
        status: 302;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Found", 302, false, T>, SeeOther: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    SeeOther: () => Simplify<T & {
        status: 303;
        ok: false;
    }, {}>;
}> | GeneralResponse<"SeeOther", 303, false, T>, NotModified: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NotModified: () => Simplify<T & {
        status: 304;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NotModified", 304, false, T>, UseProxy: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    UseProxy: () => Simplify<T & {
        status: 305;
        ok: false;
    }, {}>;
}> | GeneralResponse<"UseProxy", 305, false, T>, SwitchProxy: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    SwitchProxy: () => Simplify<T & {
        status: 305;
        ok: false;
    }, {}>;
}> | GeneralResponse<"SwitchProxy", 305, false, T>, TemporaryRedirect: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    TemporaryRedirect: () => Simplify<T & {
        status: 307;
        ok: false;
    }, {}>;
}> | GeneralResponse<"TemporaryRedirect", 307, false, T>, PermanentRedirect: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PermanentRedirect: () => Simplify<T & {
        status: 308;
        ok: false;
    }, {}>;
}> | GeneralResponse<"PermanentRedirect", 308, false, T>, BadRequest: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    BadRequest: () => Simplify<T & {
        status: 400;
        ok: false;
    }, {}>;
}> | GeneralResponse<"BadRequest", 400, false, T>, Unauthorized: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Unauthorized: () => Simplify<T & {
        status: 401;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Unauthorized", 401, false, T>, PaymentRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PaymentRequired: () => Simplify<T & {
        status: 402;
        ok: false;
    }, {}>;
}> | GeneralResponse<"PaymentRequired", 402, false, T>, Forbidden: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Forbidden: () => Simplify<T & {
        status: 403;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Forbidden", 403, false, T>, NotFound: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NotFound: () => Simplify<T & {
        status: 404;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NotFound", 404, false, T>, MethodNotAllowed: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    MethodNotAllowed: () => Simplify<T & {
        status: 405;
        ok: false;
    }, {}>;
}> | GeneralResponse<"MethodNotAllowed", 405, false, T>, 
/** [406 Not Acceptable](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/406) — indicates that the server cannot produce a response matching the list of acceptable values defined in the request's proactive [content negotiation](https://developer.mozilla.org/en-US/docs/Web/HTTP/Content_negotiation) headers, and that the server is unwilling to supply a default representation. */
NotAcceptable: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NotAcceptable: () => Simplify<T & {
        status: 406;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NotAcceptable", 406, false, T>, ProxyAuthenticationRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    ProxyAuthenticationRequired: () => Simplify<T & {
        status: 407;
        ok: false;
    }, {}>;
}> | GeneralResponse<"ProxyAuthenticationRequired", 407, false, T>, RequestTimeout: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    RequestTimeout: () => Simplify<T & {
        status: 408;
        ok: false;
    }, {}>;
}> | GeneralResponse<"RequestTimeout", 408, false, T>, Conflict: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Conflict: () => Simplify<T & {
        status: 409;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Conflict", 409, false, T>, Gone: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Gone: () => Simplify<T & {
        status: 410;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Gone", 410, false, T>, LengthRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    LengthRequired: () => Simplify<T & {
        status: 411;
        ok: false;
    }, {}>;
}> | GeneralResponse<"LengthRequired", 411, false, T>, PreconditionFailed: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PreconditionFailed: () => Simplify<T & {
        status: 412;
        ok: false;
    }, {}>;
}> | GeneralResponse<"PreconditionFailed", 412, false, T>, PayloadTooLarge: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PayloadTooLarge: () => Simplify<T & {
        status: 413;
        ok: false;
    }, {}>;
}> | GeneralResponse<"PayloadTooLarge", 413, false, T>, URITooLong: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    URITooLong: () => Simplify<T & {
        status: 414;
        ok: false;
    }, {}>;
}> | GeneralResponse<"URITooLong", 414, false, T>, UnsupportedMediaType: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    UnsupportedMediaType: () => Simplify<T & {
        status: 415;
        ok: false;
    }, {}>;
}> | GeneralResponse<"UnsupportedMediaType", 415, false, T>, RangeNotSatisfiable: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    RangeNotSatisfiable: () => Simplify<T & {
        status: 416;
        ok: false;
    }, {}>;
}> | GeneralResponse<"RangeNotSatisfiable", 416, false, T>, ExpectationFailed: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    ExpectationFailed: () => Simplify<T & {
        status: 417;
        ok: false;
    }, {}>;
}> | GeneralResponse<"ExpectationFailed", 417, false, T>, ImATeapot: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    ImATeapot: () => Simplify<T & {
        status: 418;
        ok: false;
    }, {}>;
}> | GeneralResponse<"ImATeapot", 418, false, T>, MisdirectedRequest: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    MisdirectedRequest: () => Simplify<T & {
        status: 421;
        ok: false;
    }, {}>;
}> | GeneralResponse<"MisdirectedRequest", 421, false, T>, UnprocessableEntity: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    UnprocessableEntity: () => Simplify<T & {
        status: 422;
        ok: false;
    }, {}>;
}> | GeneralResponse<"UnprocessableEntity", 422, false, T>, Locked: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    Locked: () => Simplify<T & {
        status: 423;
        ok: false;
    }, {}>;
}> | GeneralResponse<"Locked", 423, false, T>, FailedDependency: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    FailedDependency: () => Simplify<T & {
        status: 424;
        ok: false;
    }, {}>;
}> | GeneralResponse<"FailedDependency", 424, false, T>, TooEarly: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    TooEarly: () => Simplify<T & {
        status: 425;
        ok: false;
    }, {}>;
}> | GeneralResponse<"TooEarly", 425, false, T>, UpgradeRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    UpgradeRequired: () => Simplify<T & {
        status: 426;
        ok: false;
    }, {}>;
}> | GeneralResponse<"UpgradeRequired", 426, false, T>, PreconditionRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    PreconditionRequired: () => Simplify<T & {
        status: 428;
        ok: false;
    }, {}>;
}> | GeneralResponse<"PreconditionRequired", 428, false, T>, TooManyRequests: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    TooManyRequests: () => Simplify<T & {
        status: 429;
        ok: false;
    }, {}>;
}> | GeneralResponse<"TooManyRequests", 429, false, T>, RequestHeaderFieldsTooLarge: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    RequestHeaderFieldsTooLarge: () => Simplify<T & {
        status: 431;
        ok: false;
    }, {}>;
}> | GeneralResponse<"RequestHeaderFieldsTooLarge", 431, false, T>, UnavailableForLegalReasons: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    UnavailableForLegalReasons: () => Simplify<T & {
        status: 451;
        ok: false;
    }, {}>;
}> | GeneralResponse<"UnavailableForLegalReasons", 451, false, T>, InternalServerError: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    InternalServerError: () => Simplify<T & {
        status: 500;
        ok: false;
    }, {}>;
}> | GeneralResponse<"InternalServerError", 500, false, T>, NotImplemented: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NotImplemented: () => Simplify<T & {
        status: 501;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NotImplemented", 501, false, T>, BadGateway: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    BadGateway: () => Simplify<T & {
        status: 502;
        ok: false;
    }, {}>;
}> | GeneralResponse<"BadGateway", 502, false, T>, ServiceUnavailable: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    ServiceUnavailable: () => Simplify<T & {
        status: 503;
        ok: false;
    }, {}>;
}> | GeneralResponse<"ServiceUnavailable", 503, false, T>, GatewayTimeout: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    GatewayTimeout: () => Simplify<T & {
        status: 504;
        ok: false;
    }, {}>;
}> | GeneralResponse<"GatewayTimeout", 504, false, T>, HTTPVersionNotSupported: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    HTTPVersionNotSupported: () => Simplify<T & {
        status: 505;
        ok: false;
    }, {}>;
}> | GeneralResponse<"HTTPVersionNotSupported", 505, false, T>, VariantAlsoNegotiates: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    VariantAlsoNegotiates: () => Simplify<T & {
        status: 506;
        ok: false;
    }, {}>;
}> | GeneralResponse<"VariantAlsoNegotiates", 506, false, T>, InsufficientStorage: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    InsufficientStorage: () => Simplify<T & {
        status: 507;
        ok: false;
    }, {}>;
}> | GeneralResponse<"InsufficientStorage", 507, false, T>, LoopDetected: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    LoopDetected: () => Simplify<T & {
        status: 508;
        ok: false;
    }, {}>;
}> | GeneralResponse<"LoopDetected", 508, false, T>, NotExtended: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NotExtended: () => Simplify<T & {
        status: 510;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NotExtended", 510, false, T>, NetworkAuthenticationRequired: <T extends Options = {}>(obj?: T | undefined) => APIResponse<{
    NetworkAuthenticationRequired: () => Simplify<T & {
        status: 511;
        ok: false;
    }, {}>;
}> | GeneralResponse<"NetworkAuthenticationRequired", 511, false, T>;
export {};
